==> zio-aws-backupgateway_3-5.17.271.1-sources.jar: zio/aws/backupgateway/model/ListVirtualMachinesRequest.scala <==
package zio.aws.backupgateway.model
import zio.aws.backupgateway.model.primitives.{NextToken, MaxResults}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListVirtualMachinesRequest(
    maxResults: Optional[MaxResults] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.backupgateway.model.ListVirtualMachinesRequest = {
    import ListVirtualMachinesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.backupgateway.model.ListVirtualMachinesRequest
      .builder()
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.backupgateway.model.ListVirtualMachinesRequest.ReadOnly =
    zio.aws.backupgateway.model.ListVirtualMachinesRequest.wrap(buildAwsValue())
}
object ListVirtualMachinesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.backupgateway.model.ListVirtualMachinesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.backupgateway.model.ListVirtualMachinesRequest =
      zio.aws.backupgateway.model.ListVirtualMachinesRequest(
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def maxResults: Optional[MaxResults]
    def nextToken: Optional[NextToken]
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.backupgateway.model.ListVirtualMachinesRequest
  ) extends zio.aws.backupgateway.model.ListVirtualMachinesRequest.ReadOnly {
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.backupgateway.model.primitives.MaxResults(value))
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.backupgateway.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.backupgateway.model.ListVirtualMachinesRequest
  ): zio.aws.backupgateway.model.ListVirtualMachinesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-backupgateway_3-5.19.7.3-sources.jar: zio/aws/backupgateway/model/ListVirtualMachinesRequest.scala <==
package zio.aws.backupgateway.model
import zio.aws.backupgateway.model.primitives.{NextToken, MaxResults, ServerArn}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListVirtualMachinesRequest(
    hypervisorArn: Optional[ServerArn] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.backupgateway.model.ListVirtualMachinesRequest = {
    import ListVirtualMachinesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.backupgateway.model.ListVirtualMachinesRequest
      .builder()
      .optionallyWith(
        hypervisorArn.map(value => ServerArn.unwrap(value): java.lang.String)
      )(_.hypervisorArn)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.backupgateway.model.ListVirtualMachinesRequest.ReadOnly =
    zio.aws.backupgateway.model.ListVirtualMachinesRequest.wrap(buildAwsValue())
}
object ListVirtualMachinesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.backupgateway.model.ListVirtualMachinesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.backupgateway.model.ListVirtualMachinesRequest =
      zio.aws.backupgateway.model.ListVirtualMachinesRequest(
        hypervisorArn.map(value => value),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def hypervisorArn: Optional[ServerArn]
    def maxResults: Optional[MaxResults]
    def nextToken: Optional[NextToken]
    def getHypervisorArn: ZIO[Any, AwsError, ServerArn] =
      AwsError.unwrapOptionField("hypervisorArn", hypervisorArn)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.backupgateway.model.ListVirtualMachinesRequest
  ) extends zio.aws.backupgateway.model.ListVirtualMachinesRequest.ReadOnly {
    override val hypervisorArn: Optional[ServerArn] = zio.aws.core.internal
      .optionalFromNullable(impl.hypervisorArn())
      .map(value => zio.aws.backupgateway.model.primitives.ServerArn(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.backupgateway.model.primitives.MaxResults(value))
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.backupgateway.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.backupgateway.model.ListVirtualMachinesRequest
  ): zio.aws.backupgateway.model.ListVirtualMachinesRequest.ReadOnly =
    new Wrapper(impl)
}
